@@ -4,6 +4,8 @@ import requests
 
 init(convert=True)
 
+__app_name__ = "pie-manager"
+
 def parent_dir(path: str):
     return os.path.abspath(os.path.join(path, os.pardir))
 
@@ -52,13 +54,8 @@ def many_in_check(*list, iterable=None):
 def entry_point():
     if many_in_check("-U", "--upgrade", "--install", "-I", iterable=(i.lower() for i in sys.argv)):
         main()
-        exit()
-
-    print(Fore.RED + "Please use '--upgrade' '-U', '--install', '-I' to install/upgrade pie." + Fore.RESET)
+    else:
+        print(Fore.RED + "Please use '--upgrade' '-U', '--install', '-I' to install/upgrade pie." + Fore.RESET)
 
 if __name__ == "__main__":
-    if many_in_check("-U", "--upgrade", "--install", "-I", iterable=(i.lower() for i in sys.argv)):
-        main()
-        exit()
-
-    print(Fore.RED + "Please use '--upgrade' '-U', '--install', '-I' to install/upgrade pie." + Fore.RESET)
\ No newline at end of file
+    entry_point()
\ No newline at end of file
